//Database.js

// First, let's create a short helper function to get the database connection
function getDatabase() {
     return openDatabaseSync("SkyFM", "1.0", "StorageDatabase", 100000);
}

// At the start of the application, we can initialize the tables we need if they haven't been created yet
function initialize() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Create the settings table if it doesn't already exist
            // If the table exists, this is skipped
            tx.executeSql('CREATE TABLE IF NOT EXISTS favorites(track_id INTEGER UNIQUE, artist TEXT, title TEXT, art TEXT)');
            tx.executeSql('CREATE TABLE IF NOT EXISTS settings(name TEXT UNIQUE, value TEXT)');
      });
}

function setSetting(name, value) {
    var db = getDatabase();
    var res = "Error";
    db.transaction(function(tx) {
         var rs = tx.executeSql('INSERT OR REPLACE INTO settings VALUES (?,?);', [name,value]);
               //console.log(rs.rowsAffected)
               if (rs.rowsAffected > 0) {
                 res = "OK";
               } else {
                 res = "Error";
               }
         }
   );
   // The function returns “OK” if it was successful, or “Error” if it wasn't
   return res;
}

function getSetting(name) {
    var db = getDatabase();
    var res = "Error";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('select value FROM settings WHERE name = ?;', [name]);
                       if (rs.rows.length > 0) {
                            res = rs.rows.item(0).value
                       }
                   })
    return res;
}

// This function is used to write a favorite record into the database
function addToFavorites(key, artist, track, art) {
   // setting: string representing the setting name (eg: “username”)
   // value: string representing the value of the setting (eg: “myUsername”)
   var db = getDatabase();
   var res = "";
   db.transaction(function(tx) {
        var rs = tx.executeSql('INSERT OR REPLACE INTO favorites VALUES (?,?,?,?);', [key,artist,track,art]);
              //console.log(rs.rowsAffected)
              if (rs.rowsAffected > 0) {
                res = "OK";
              } else {
                res = "Error";
              }
        }
  );
  // The function returns “OK” if it was successful, or “Error” if it wasn't
  return res;
}
// This function is used to retrieve a list of favorite tracks from the database
function getFavorites() {
    var db = getDatabase();
    var err = "Error";
    var res = new Array;
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT * FROM favorites');
                       if (rs.rows.length > 0) {
                           for(var i = 0; i < rs.rows.length; i++) {
                               res.push(rs.rows.item(i));
                           }
                       }
                   })
    // The function returns “Unknown” if the setting was not found in the database
    // For more advanced projects, this should probably be handled through error codes
    if(res.length > 0) {
        return res;
    } else {
        return err;
    }
}

function isTrackPresent(track_id) {
    var db = getDatabase();
    var res = false;
    db.transaction(function(tx) {
                       var request = 'select * FROM favorites WHERE track_id = ' + track_id + ';'
                       var rs = tx.executeSql(request);
                       if (rs.rows.length > 0) {
                           res = true;
                       }
                   });
    return res;

}

function deleteRecord(track_id) {
    var db = getDatabase();
    var res = false;
    db.transaction(function(tx) {
                       var request = 'DELETE FROM favorites WHERE track_id = ' + track_id + ';'
                       res = tx.executeSql(request);
                   });
    return res;
}

//drop the base
function dropTheBase() {
    var db = getDatabase();
    db.transaction(
        function(tx) {
            // Delete the favorites table if it already exists
//            tx.executeSql('DROP TABLE IF EXISTS favorites');
            tx.executeSql('DROP TABLE IF EXISTS settings');
      });
}
