import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1     // Extras

import "Database.js" as FavList

Page {
    orientationLock: PageOrientation.LockPortrait

    property string recordForDelete: ""

    ListModel {
        id: favList
    }

    function getFavorites() {
        var res = FavList.getFavorites();
        if (res.constructor === Array) {
            emptyBase.visible = false;
            for(var i in res) {
                favList.append({id: res[i].track_id, artist: res[i].artist, title: res[i].title, art: res[i].art});
            }
            favListView.visible = true;
        } else {
            emptyBase.visible = true;
            favListView.visible = false;
            infoBanner.text = "The base is empty"
//            infoBanner.show();
        }
    }

    Component.onCompleted: {
        FavList.initialize();
        getFavorites();
    }

    Component {
        id: favListComponent
        Item {
            id: baseItem
            width: parent.width
            height: 138
            Image {
                id: icon
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                fillMode: Image.PreserveAspectFit
                width: 128
                height: 128
                source: art
            }
            Label {
                id: authorName
                anchors.left: icon.right
                anchors.top: icon.top
                anchors.right: parent.right
                anchors.margins: 10
                text: "Artist: " + artist
            }
            Label {
                id: track
                anchors.left: icon.right
                anchors.top: authorName.bottom
                anchors.right: parent.right
                anchors.margins: 10
                text: "Track: " + title
            }
            Rectangle {
                id: delimeter
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.98
                height: 3
                radius: 10
                smooth: true
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: "gray" }
                    GradientStop { position: 0.33; color: "white" }
                    GradientStop { position: 1.0; color: "lightgray" }
                }
            }
            MouseArea {
                anchors.fill: parent
                onPressAndHold: {
                    recordForDelete = id;
                    deleteRecord.open();
                }
                onClicked: {
                    var link = "https://www.google.com/search?&q=" + artist + " " + title;
                    Qt.openUrlExternally(link);
                }
            }
        }
    }

    InfoBanner {
        id: infoBanner
        text: ""
        timerShowTime: 2000
    }

    BusyIndicator {
        id: busyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    QueryDialog {
        id: deleteRecord
        title: Text {
            text: qsTr("Delete track")
            anchors.centerIn: parent;
            color: "white"
            font.pixelSize: 28
            font.bold: true
        }
        message: qsTr("Record will be deleted")
        acceptButtonText: qsTr("Delete")
        rejectButtonText: qsTr("Cancel")
        onAccepted: {
            FavList.deleteRecord(recordForDelete);
            favList.clear();
            getFavorites();
            deleteRecord.close()
        }
        onRejected: {
            deleteRecord.close()
        }
    }

    ListView {
        id: favListView
        anchors.fill: parent
        visible: false
        model: favList
        delegate: favListComponent
        spacing: 5
        clip: true
    }

    Label {
        id: emptyBase
        anchors.centerIn: parent
        visible: true
        text: qsTr("The favorite list is empty")
    }

    tools: ToolBarLayout {
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            enabled: true
            onClicked: {
                pageStack.pop();
            }
        }
    }

}
