import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1     // Extras

import "Database.js" as Database

Page {
    id: logInPage
    orientationLock: PageOrientation.LockPortrait

    property string key: ""
    property string post_params: ""

    function sendPostHttpRequest(url, callback) {
        var doc = new XMLHttpRequest();
        doc.onreadystatechange = function() {
                    if (doc.readyState == 4) {
                        console.log("http response", doc.status, "\nText: ", doc.responseText)
                        if (doc.status == 200) {
                            callback(doc.responseText);
                        } else {
                            callback("error");
                            console.log("http error response", doc.status, "\nText: ", doc.responseText)
//                            infoBanner.text = qsTr("Error happened during data receiving");
//                            infoBanner.show();
                        }
                    }
                }
        doc.open("POST", url);
        doc.setRequestHeader('Content-type', 'application/x-www-form-urlencoded');
//        console.log("send url", url)
        doc.send(post_params);
    }

    function sendHttpRequest(url, callback) {
        var doc = new XMLHttpRequest();
        doc.onreadystatechange = function() {
                    if (doc.readyState == 4) {
//                        console.log("http response", doc.status, "\nText: ", doc.responseText)
                        if (doc.status == 200) {
                            callback(doc.responseText);
                        } else {
                            callback("error");
                            infoBanner.text = qsTr("Error happened during data receiving");
                            infoBanner.show();
                        }
                    }
                }
        doc.open("GET", url);
//        console.log("send url", url)
        doc.send();
    }

    Component.onCompleted: {
        Database.initialize();
        busyIndicator.visible = true;
        busyIndicator.running = true;
        var api_key = Database.getSetting("api_key");
        if(api_key !== 'Error') {
            var url = "https://api.audioaddict.com/v1/di/members/authenticate";
            post_params = "api_key=" + api_key
            sendPostHttpRequest(url, userInfo.processData);
        } else {
            logIn.visible = true;

            busyIndicator.running = false;
            busyIndicator.visible = false;
        }

        var price_url = "http://api.audioaddict.com/v1/rockradio/plans/premium-pass"
        sendHttpRequest(price_url, setPrices)
    }

    function setPrices(data) {
//        console.log(data)
        if(data !== "error") {
            var tmp = JSON.parse(data)
            for(var i in tmp.price_sets[0].price_set_options) {
                console.log(JSON.stringify(tmp.price_sets[0].price_set_options[i]))
                var el = tmp.price_sets[0].price_set_options[i];
                pricesModel.append({price_string: el.formatted_price_string, term_unit: el.term_unit, term_duration: el.term_duration, label: el.label})
            }
            busyIndicator.running = false;
            busyIndicator.visible = false;
            premItem.visible = true
        }
    }

    BusyIndicator {
        id: busyIndicator
        anchors.centerIn: parent
        running: false
        visible: false
        platformStyle: BusyIndicatorStyle { size: "large" }
    }


    InfoBanner {
        id: infoBanner
        text: ""
        timerShowTime: 2000
    }

    ListModel {
        id: pricesModel
    }

    Component {
        id: pricesModelDelegate
        Item {
            height: 60
            width: logInPage.width
            Label {
                anchors.left: parent.left
                anchors.top: parent.top
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
                text: price_string + " for " + term_duration + " " + term_unit
            }
            Label {
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
                text: label?"(" + label + ")":""
            }
        }
    }


        Item {
            anchors.top: parent.top
            anchors.left: parent.left
            width: parent.width
            height: parent.height * 0.5
            Item {
                id: logIn
                anchors.fill: parent
                visible: false
                Column {
                    anchors.centerIn: parent
                    spacing: 5
                    Label {
                        id: usernameLabel
                        text: "Username"
                        anchors.left: parent.left
                    }
                    TextField {
                        id: username
                        width: parent.width
                        text: ""
                        placeholderText: "Input username here..."
                     }
                    Label {
                        id: passwordLabel
                        text: "Password"
                        anchors.left: parent.left
                    }
                    TextField {
                        id: password
                        width: parent.width
                        text: ""
                        placeholderText: "Input password here..."
                        echoMode: TextInput.Password
                     }
                    Button {
                        id: logInButton
                        anchors.horizontalCenter: parent.horizontalCenter
                        text: "Log in"
                        onClicked: {
                            var url = "https://api.audioaddict.com/v1/di/members/authenticate";
                            post_params = "username=" + username.text + "&password=" + password.text
                            sendPostHttpRequest(url, userInfo.processData);
                        }
                    }
                }
            }

            Item {
                id: userInfo

                property variant userData
                anchors.fill: parent
                visible: false

                function processData(data) {
        //            console.log(data)
                    if(data !== 'error') {
                        userData = JSON.parse(data);
                        var lastEl = userData.subscriptions.length - 1;
        //                console.log(JSON.stringify(userData))
                        if(userData.api_key) {
                            Database.setSetting("api_key", userData.api_key)
                        }
                        if(userData.listen_key) {
                            Database.setSetting("listen_key", userData.listen_key)
                        }
                        if(userData.subscriptions[lastEl].status) {
                            Database.setSetting("status", userData.subscriptions[lastEl].status)
                        }
                        firstLastName.text = userData.first_name + " " + userData.last_name
                        expires.text = userData.subscriptions[lastEl].expires_on
                        if(userData.subscriptions[lastEl].status === 'expired') {
                            expires.errorHighlight = true
                        } else {
                            expires.errorHighlight = false
                        }

                        logIn.visible = false
                        userInfo.visible = true
                    } else {
                        infoBanner.text = qsTr("Incorrect login or password");
                        infoBanner.show();
                        logIn.visible = true
                        userInfo.visible = false
                    }

                    busyIndicator.running = false;
                    busyIndicator.visible = false;
                }
                Column {
                    anchors.centerIn: parent
                    spacing: 5
                    Label {
                        text: "Username"
                        anchors.left: parent.left
                    }
                    TextField {
                        id: firstLastName
        //                width: parent.width
                        text: ""
                        readOnly: true
                     }
                    Label {
                        id: expiresLabel
                        text: "Premium expires on"
                        anchors.left: parent.left
                    }
                    TextField {
                        id: expires
        //                width: parent.width
                        text: ""
                        readOnly: true
                     }
                }

            }
        }

        Item {
            id: premItem
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            width: parent.width
            height: parent.height * 0.5
            visible: false
            Column {
                spacing: 5
                Rectangle {
                    id: delimeter
//                    anchors.top: parent.top
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width * 0.98
                    height: 3
                    radius: 10
                    smooth: true
                    gradient:  Gradient {
                        GradientStop { position: 0.0; color: "gray" }
                        GradientStop { position: 0.33; color: "white" }
                        GradientStop { position: 1.0; color: "lightgray" }
                    }
                }
                Label {
                    text: "Prices"
                    width: parent.width
                    font.bold: true
                    font.pointSize: 26
                    horizontalAlignment: Text.AlignHCenter
                }

                Repeater {
                    model: pricesModel
                    delegate: pricesModelDelegate
                }
                Button {
                    id: goPrem
//                    anchors.left: parent.left
//                    anchors.right: parent.right
                    anchors.horizontalCenter: parent.horizontalCenter
//                    width: parent.width
//                    horizontalAlignment: Text.AlignHCenter
                    text: "Get premium"
                    font.pointSize: 26
                    onClicked: {
                        Qt.openUrlExternally('https://www.di.fm/premium');
                    }
                }
            }
        }

    tools: ToolBarLayout {
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            enabled: true
            onClicked: {
                pageStack.pop();
            }
        }
    }
}
